import 'package:comunic/enums/post_target.dart';
import 'package:comunic/helpers/posts_helper.dart';
import 'package:comunic/models/advanced_user_info.dart';
import 'package:comunic/ui/widgets/post_create_form_widget.dart';
import 'package:comunic/ui/widgets/posts_list_widget.dart';
import 'package:flutter/material.dart';

/// Tablet mode of user page
///
/// @author Pierre HUBERT

class UserPageTablet extends StatefulWidget {
  final AdvancedUserInfo userInfo;
  final void Function() onNeedRefresh;

  const UserPageTablet({
    Key key,
    @required this.userInfo,
    @required this.onNeedRefresh,
  })  : assert(userInfo != null),
        assert(onNeedRefresh != null),
        super(key: key);

  @override
  _UserPageTabletState createState() => _UserPageTabletState();
}

class _UserPageTabletState extends State<UserPageTablet> {
  AdvancedUserInfo get _userInfo => widget.userInfo;

  @override
  Widget build(BuildContext context) => Flex(
        direction: Axis.horizontal,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          _buildLeftColumn(),
          Expanded(child: _buildRightColumn())
        ],
      );

  Widget _buildLeftColumn() => Text("Here comes the head");

  Widget _buildRightColumn() => PostsListWidget(
        disablePullToRefresh: true,
        topWidgets: [
          _userInfo.canPostTexts
              ? PostCreateFormWidget(
                  postTarget: PostTarget.USER_PAGE,
                  targetID: _userInfo.id,
                  onCreated: widget.onNeedRefresh,
                )
              : Container()
        ],
        getPostsList: () => PostsHelper().getUserPosts(_userInfo.id),
        getOlder: (from) =>
            PostsHelper().getUserPosts(_userInfo.id, from: from),
        showPostsTarget: false,
      );
}
